==> ios_rotate_image-0.0.15.tar.gz: ios/Classes/IosRotateImagePlugin.m <==
#import "IosRotateImagePlugin.h"


@implementation IosRotateImagePlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"ios_rotate_image"
            binaryMessenger:[registrar messenger]];
  IosRotateImagePlugin* instance = [[IosRotateImagePlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"rotateImage" isEqualToString:call.method]) {
      NSString *path = call.arguments[@"path"];
      // check if a file exists
      if ([UIImage imageNamed:path]) {
          // if it exists, change the rotation mode
          UIImage * landscapeImage = [UIImage imageNamed:path];
          UIImage * portraitImage = rotatedImage(landscapeImage, 897.0);
          NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
          NSString* documentsDirectory = [paths objectAtIndex:0];
          NSString* path = [documentsDirectory stringByAppendingPathComponent: @"test.png"];
          NSData* data = UIImagePNGRepresentation(portraitImage);
          [data writeToFile:path atomically:YES];
          result(path);
//          UIImage * landscapeImage = [UIImage imageNamed:path];
//          UIImage * portraitImage = [[UIImage alloc] initWithCGImage: landscapeImage.CGImage
//                                                               scale: 1.0
//                                                         orientation: UIImageOrientationRight];
//          NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
//          NSString* documentsDirectory = [paths objectAtIndex:0];
//          NSString* path = [documentsDirectory stringByAppendingPathComponent: @"test.png"];
//          NSData* data = UIImagePNGRepresentation(portraitImage);
//          [data writeToFile:path atomically:YES];
//          result(path);
      } else {
          result(FlutterMethodNotImplemented);
          return;
      }
      result(@"OK");
  } else {
    result(FlutterMethodNotImplemented);
    return;
  }
}

UIImage *rotatedImage(UIImage *image, CGFloat rotation) // rotation in radians
{
    // Calculate Destination Size
    CGAffineTransform t = CGAffineTransformMakeRotation(rotation);
    CGRect sizeRect = (CGRect) {.size = image.size};
    CGRect destRect = CGRectApplyAffineTransform(sizeRect, t);
    CGSize destinationSize = destRect.size;
    // Draw image
    UIGraphicsBeginImageContext(destinationSize);
    CGContextRef context = UIGraphicsGetCurrentContext();
    CGContextTranslateCTM(context, destinationSize.width / 2.0f, destinationSize.height / 2.0f);
    CGContextRotateCTM(context, rotation);
    [image drawInRect:CGRectMake(-image.size.width / 2.0f, -image.size.height / 2.0f, image.size.width, image.size.height)];
    // Save image
    UIImage *newImage = UIGraphicsGetImageFromCurrentImageContext();
    UIGraphicsEndImageContext();
    return newImage;
}
CGFloat DegreesToRadians(CGFloat degrees)
{
    return degrees * M_PI / 180;
};
CGFloat RadiansToDegrees(CGFloat radians)
{
    return radians * 180 / M_PI;
};

@end

==> ios_rotate_image-0.0.16.tar.gz: ios/Classes/IosRotateImagePlugin.m <==
#import "IosRotateImagePlugin.h"


@implementation IosRotateImagePlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"ios_rotate_image"
            binaryMessenger:[registrar messenger]];
  IosRotateImagePlugin* instance = [[IosRotateImagePlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"rotateImage" isEqualToString:call.method]) {
      NSString *path = call.arguments[@"path"];
      NSString *radius = call.arguments[@"radius"];
      float value = [radius floatValue];
      // check if a file exists
      if ([UIImage imageNamed:path]) {
          // if it exists, change the rotation mode
          UIImage * landscapeImage = [UIImage imageNamed:path];
          UIImage * portraitImage = rotatedImage(landscapeImage, value);
          NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
          NSString* documentsDirectory = [paths objectAtIndex:0];
          NSString* path = [documentsDirectory stringByAppendingPathComponent: @"test.png"];
          NSData* data = UIImagePNGRepresentation(portraitImage);
          [data writeToFile:path atomically:YES];
          result(path);
//          UIImage * landscapeImage = [UIImage imageNamed:path];
//          UIImage * portraitImage = [[UIImage alloc] initWithCGImage: landscapeImage.CGImage
//                                                               scale: 1.0
//                                                         orientation: UIImageOrientationRight];
//          NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
//          NSString* documentsDirectory = [paths objectAtIndex:0];
//          NSString* path = [documentsDirectory stringByAppendingPathComponent: @"test.png"];
//          NSData* data = UIImagePNGRepresentation(portraitImage);
//          [data writeToFile:path atomically:YES];
//          result(path);
      } else {
          result(FlutterMethodNotImplemented);
          return;
      }
      result(@"OK");
  } else {
    result(FlutterMethodNotImplemented);
    return;
  }
}

UIImage *rotatedImage(UIImage *image, CGFloat rotation) // rotation in radians
{
    // Calculate Destination Size
    CGAffineTransform t = CGAffineTransformMakeRotation(rotation);
    CGRect sizeRect = (CGRect) {.size = image.size};
    CGRect destRect = CGRectApplyAffineTransform(sizeRect, t);
    CGSize destinationSize = destRect.size;
    // Draw image
    UIGraphicsBeginImageContext(destinationSize);
    CGContextRef context = UIGraphicsGetCurrentContext();
    CGContextTranslateCTM(context, destinationSize.width / 2.0f, destinationSize.height / 2.0f);
    CGContextRotateCTM(context, rotation);
    [image drawInRect:CGRectMake(-image.size.width / 2.0f, -image.size.height / 2.0f, image.size.width, image.size.height)];
    // Save image
    UIImage *newImage = UIGraphicsGetImageFromCurrentImageContext();
    UIGraphicsEndImageContext();
    return newImage;
}
CGFloat DegreesToRadians(CGFloat degrees)
{
    return degrees * M_PI / 180;
};
CGFloat RadiansToDegrees(CGFloat radians)
{
    return radians * 180 / M_PI;
};

@end
